@@ -14,7 +14,7 @@
         Hampshire, GU31 5DG
         United Kingdom
 
-        Copyright (C) 2005
+        Copyright (C) 2005,2016
         Helge Kreutzmann <debian@helgefjell.de>
 
         Version Author  Date            Comments
@@ -25,6 +25,7 @@
         1.0.3   OPAL    20021225	Rewritten some for hppa.
 	1.0.4   KRE     20050318        Print CPU
 	1.0.5   KRE     20051118        Include <string.h>
+	1.0.6   KRE     20160918        Determine fastest CPU
 
         This is the hppa port of linuxinfo
 */
@@ -103,7 +104,10 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 			}
 
 			if (strncasecmp(temp_string, "cpu MHz", strlen("cpu MHz")) == 0)
-				tempMHz = atol(temp_string2);
+			{
+				if (atol(temp_string2) > tempMHz)
+					tempMHz = atol(temp_string2);
+			}
 
 			if (strncasecmp(temp_string, "bogomips", strlen("bogomips")) == 0)
 				bogomips = bogomips + atof(temp_string2);
